documentationtools.ModuleCrawler
================================

.. abjad-lineage:: abjad.tools.documentationtools.ModuleCrawler.ModuleCrawler

.. autoclass:: abjad.tools.documentationtools.ModuleCrawler.ModuleCrawler

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.documentationtools.ModuleCrawler.ModuleCrawler.code_root
      ~abjad.tools.documentationtools.ModuleCrawler.ModuleCrawler.ignored_directory_names
      ~abjad.tools.documentationtools.ModuleCrawler.ModuleCrawler.root_package_name
      ~abjad.tools.documentationtools.ModuleCrawler.ModuleCrawler.visit_private_modules
      ~abjad.tools.documentationtools.ModuleCrawler.ModuleCrawler.__eq__
      ~abjad.tools.documentationtools.ModuleCrawler.ModuleCrawler.__format__
      ~abjad.tools.documentationtools.ModuleCrawler.ModuleCrawler.__iter__
      ~abjad.tools.documentationtools.ModuleCrawler.ModuleCrawler.__ne__
      ~abjad.tools.documentationtools.ModuleCrawler.ModuleCrawler.__repr__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.documentationtools.ModuleCrawler.ModuleCrawler.code_root
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ModuleCrawler.ModuleCrawler.ignored_directory_names
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ModuleCrawler.ModuleCrawler.root_package_name
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ModuleCrawler.ModuleCrawler.visit_private_modules
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.documentationtools.ModuleCrawler.ModuleCrawler.__eq__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ModuleCrawler.ModuleCrawler.__format__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ModuleCrawler.ModuleCrawler.__iter__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ModuleCrawler.ModuleCrawler.__ne__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ModuleCrawler.ModuleCrawler.__repr__
   :noindex:
